@@ -10,7 +10,7 @@ setGeneric("flipud",
            function(object) {
                #cat("generic", match.call()[[1]], "\n")
                standardGeneric("flipud")
-}           )
+           })
 
 setMethod("flipud",
           signature(object = "vector"),
@@ -31,20 +31,22 @@ setMethod("flipud",
           signature(object = "array"),
           function(object) {
               #cat(match.call()[[1]], "(array)", "\n")
-              stop(paste("argument", sQuote("object"), "must be vector or matrix"))
+              stop(sprintf("argument %s must be vector or matrix",
+                           sQuote("object")))
           })
 
 setMethod("flipud",
           signature(object = "ANY"),
           function(object) {
               #cat(match.call()[[1]], "(ANY)", "\n")
-              stop(paste("method not defined for", data.class(object), "argument"))
+              stop(sprintf("method not defined for %s argument",
+                           data.class(object)))
           })
 
 setMethod("flipud",
           signature(object = "missing"),
           function(object) {
               #cat(match.call()[[1]], "(missing)", "\n")
-              stop(paste("argument", sQuote("object"), "missing"))
+              stop(sprintf("argument %s missing", sQuote("object")))
           })
 
